@@ -197,30 +197,29 @@ pub mod macros {
             vec2
         }};
     }
-    /// vec_element_parse!() can be used to
-    /// parse vec item to f64,
-    /// type can be Vec\<&str\>
-    /// return Vec\<f64\>
+    /// vec_element_parse!() can be used to parse a vec element to type
+    /// type can be Vec\<&str\>,parse type
+    /// return Vec\<type\>
     /// ```rust
     /// use useful_macro::*;
-    ///let v1 = vec_element_parse!(vec!["15.", "2.9"]);
-    ///let v2 = vec_element_parse!(vec!["15", "2"]);
-    ///let v3 = vec_element_parse!(vec![".15", ".2"]);
+    ///let v1: Vec<f64> = vec_element_parse!(vec!["15.", "2.9"], f64);
+    ///let v2: Vec<i128> = vec_element_parse!(vec!["15", "2"], i128);
+    ///let v3: Vec<f32> = vec_element_parse!(vec![".15", ".2"], f32);
     ///assert_eq!(vec![15.0, 2.9], v1);
-    ///assert_eq!(vec![15.0, 2.0], v2);
+    ///assert_eq!(vec![15, 2], v2);
     ///assert_eq!(vec![0.15, 0.2], v3);
     /// ```
     #[macro_export]
     macro_rules! vec_element_parse {
-        ($vec:expr) => {{
-            let mut v2: Vec<f64> = Vec::new();
+        ($vec:expr,$type:ty) => {{
+            let mut v2: Vec<$type> = Vec::new();
             if $vec.len() > 0 {
-                match &$vec[0].parse::<f64>() {
+                match &$vec[0].parse::<$type>() {
                     Ok(r) => {
                         let vec1 = $vec.clone();
                         v2 = vec1
                             .iter()
-                            .map(|x| x.to_string().parse::<f64>().unwrap())
+                            .map(|x| x.to_string().parse::<$type>().unwrap())
                             .collect::<Vec<_>>();
                     }
                     Err(e) => {}
@@ -625,8 +624,12 @@ pub mod macros {
     }
 
     pub fn run() {
-        let re = vec_element_to_string!(vec_element_convert!(vec![15, 56, 14, 14], f64));
-        println!("{:?}", re);
+        let v1: Vec<f64> = vec_element_parse!(vec!["15.", "2.9"], f64);
+        let v2: Vec<i128> = vec_element_parse!(vec!["15", "2"], i128);
+        let v3: Vec<f32> = vec_element_parse!(vec![".15", ".2"], f32);
+        assert_eq!(vec![15.0, 2.9], v1);
+        assert_eq!(vec![15, 2], v2);
+        assert_eq!(vec![0.15, 0.2], v3);
     }
 }
 
